
# Class: SkLearnParams


Parameters specific to the SKLearn library.

URI: [https://w3id.org/neat/SkLearnParams](https://w3id.org/neat/SkLearnParams)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[ClassifierParams]++-%20sklearn_params%200..1>[SkLearnParams&#124;random_state:integer%20%3F;max_iter:integer%20%3F],[ClassifierParams])](https://yuml.me/diagram/nofunky;dir:TB/class/[ClassifierParams]++-%20sklearn_params%200..1>[SkLearnParams&#124;random_state:integer%20%3F;max_iter:integer%20%3F],[ClassifierParams])

## Referenced by Class

 *  **None** *[➞sklearn_params](classifierParams__sklearn_params.md)*  <sub>0..1</sub>  **[SkLearnParams](SkLearnParams.md)**

## Attributes


### Own

 * [➞random_state](skLearnParams__random_state.md)  <sub>0..1</sub>
     * Description: Random seed.
     * Range: [Integer](types/Integer.md)
 * [➞max_iter](skLearnParams__max_iter.md)  <sub>0..1</sub>
     * Description: Maximum iterations.
     * Range: [Integer](types/Integer.md)
